# himena-stats

[![PyPI - Version](https://img.shields.io/pypi/v/himena-stats.svg)](https://pypi.org/project/himena-stats)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/himena-stats.svg)](https://pypi.org/project/himena-stats)
[![codecov](https://codecov.io/gh/hanjinliu/himena-stats/graph/badge.svg?token=26MF1DDwWN)](https://codecov.io/gh/hanjinliu/himena-stats)

-----

![](images/window.png)

A [himena](https://github.com/hanjinliu/himena) plugin for statistical testing and
modeling using `scipy.stats` and `scikit-posthocs`.


## Installation

```console
pip install himena-stats
```

To install this plugin to your profile, manually edit the setting from `Ctrl+,` or run:

```console
himena <my-profile> --install himena-stats
```
